sequencetools
=============

.. automodule:: abjad.tools.sequencetools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.sequencetools.Sequence.Sequence

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.sequencetools.flatten_sequence.flatten_sequence
      ~abjad.tools.sequencetools.increase_elements.increase_elements
      ~abjad.tools.sequencetools.interlace_sequences.interlace_sequences
      ~abjad.tools.sequencetools.iterate_sequence_boustrophedon.iterate_sequence_boustrophedon
      ~abjad.tools.sequencetools.iterate_sequence_nwise.iterate_sequence_nwise
      ~abjad.tools.sequencetools.join_subsequences.join_subsequences
      ~abjad.tools.sequencetools.join_subsequences_by_sign_of_elements.join_subsequences_by_sign_of_elements
      ~abjad.tools.sequencetools.negate_elements.negate_elements
      ~abjad.tools.sequencetools.overwrite_elements.overwrite_elements
      ~abjad.tools.sequencetools.partition_sequence_by_counts.partition_sequence_by_counts
      ~abjad.tools.sequencetools.partition_sequence_by_ratio_of_lengths.partition_sequence_by_ratio_of_lengths
      ~abjad.tools.sequencetools.partition_sequence_by_ratio_of_weights.partition_sequence_by_ratio_of_weights
      ~abjad.tools.sequencetools.partition_sequence_by_restricted_growth_function.partition_sequence_by_restricted_growth_function
      ~abjad.tools.sequencetools.partition_sequence_by_sign_of_elements.partition_sequence_by_sign_of_elements
      ~abjad.tools.sequencetools.partition_sequence_by_value_of_elements.partition_sequence_by_value_of_elements
      ~abjad.tools.sequencetools.partition_sequence_by_weights.partition_sequence_by_weights
      ~abjad.tools.sequencetools.permute_sequence.permute_sequence
      ~abjad.tools.sequencetools.remove_elements.remove_elements
      ~abjad.tools.sequencetools.remove_repeated_elements.remove_repeated_elements
      ~abjad.tools.sequencetools.remove_subsequence_of_weight_at_index.remove_subsequence_of_weight_at_index
      ~abjad.tools.sequencetools.repeat_elements.repeat_elements
      ~abjad.tools.sequencetools.repeat_sequence.repeat_sequence
      ~abjad.tools.sequencetools.repeat_sequence_to_length.repeat_sequence_to_length
      ~abjad.tools.sequencetools.repeat_sequence_to_weight.repeat_sequence_to_weight
      ~abjad.tools.sequencetools.replace_elements.replace_elements
      ~abjad.tools.sequencetools.retain_elements.retain_elements
      ~abjad.tools.sequencetools.reverse_sequence.reverse_sequence
      ~abjad.tools.sequencetools.rotate_sequence.rotate_sequence
      ~abjad.tools.sequencetools.splice_between_elements.splice_between_elements
      ~abjad.tools.sequencetools.split_sequence.split_sequence
      ~abjad.tools.sequencetools.sum_consecutive_elements_by_sign.sum_consecutive_elements_by_sign
      ~abjad.tools.sequencetools.sum_elements.sum_elements
      ~abjad.tools.sequencetools.truncate_sequence.truncate_sequence
      ~abjad.tools.sequencetools.yield_all_combinations_of_elements.yield_all_combinations_of_elements
      ~abjad.tools.sequencetools.yield_all_k_ary_sequences_of_length.yield_all_k_ary_sequences_of_length
      ~abjad.tools.sequencetools.yield_all_pairs_between_sequences.yield_all_pairs_between_sequences
      ~abjad.tools.sequencetools.yield_all_partitions_of_sequence.yield_all_partitions_of_sequence
      ~abjad.tools.sequencetools.yield_all_permutations_of_sequence.yield_all_permutations_of_sequence
      ~abjad.tools.sequencetools.yield_all_permutations_of_sequence_in_orbit.yield_all_permutations_of_sequence_in_orbit
      ~abjad.tools.sequencetools.yield_all_restricted_growth_functions_of_length.yield_all_restricted_growth_functions_of_length
      ~abjad.tools.sequencetools.yield_all_rotations_of_sequence.yield_all_rotations_of_sequence
      ~abjad.tools.sequencetools.yield_all_set_partitions_of_sequence.yield_all_set_partitions_of_sequence
      ~abjad.tools.sequencetools.yield_all_subsequences_of_sequence.yield_all_subsequences_of_sequence
      ~abjad.tools.sequencetools.yield_all_unordered_pairs_of_sequence.yield_all_unordered_pairs_of_sequence
      ~abjad.tools.sequencetools.yield_outer_product_of_sequences.yield_outer_product_of_sequences
      ~abjad.tools.sequencetools.zip_sequences.zip_sequences
